((Drupal, once, Tobii) => {
  function refreshTobii() {
    // Initialize Tobii for lightbox images.
    // eslint-disable-next-line no-unused-vars
    const tobii = new Tobii({
      selector: '.lightbox-image',
      captionsSelector: 'self',
      captionAttribute: 'data-caption',
    });
  }

  // Drupal behavior that will initialize tobii on page load and updates.
  Drupal.behaviors.tobii = {
    attach(context) {
      let refresh = false;
      once(
        'lightbox-tobii-group',
        '[data-lightbox-container]',
        context,
      ).forEach((group) => {
        group.querySelectorAll('a.lightbox-image').forEach((a) => {
          // Find the nearest <figure> element and its <figcaption> child.
          const figcaption = a.closest('figure')?.querySelector('figcaption');
          // Retrieve the 'alt' attribute from the <img> tag inside the <a>.
          const alt = a.querySelector('img')?.getAttribute('alt') || '';
          // Use the <figcaption> content if it exists, fall back to 'alt'.
          const caption = figcaption ? figcaption.textContent.trim() : alt;
          // Set 'data-group' attribute to value of  'data-lightbox-container'.
          a.setAttribute(
            'data-group',
            group.getAttribute('data-lightbox-container'),
          );
          // Set 'data-caption' attribute.
          a.setAttribute('data-caption', caption);
        });
        refresh = true;
      });
      // We now search for all lightbox images not already initialized.
      once(
        'lightbox-tobii-image',
        'a.lightbox-image:not([data-group])',
        context,
      ).forEach((a, index) => {
        // Find the nearest <figure> element and its <figcaption> child.
        const figcaption = a.closest('figure')?.querySelector('figcaption');
        // Retrieve the 'alt' attribute from the <img> tag inside the <a>.
        const alt = a.querySelector('img')?.getAttribute('alt') || '';
        // Use the <figcaption> content if it exists, fall back to 'alt'.
        const caption = figcaption ? figcaption.textContent.trim() : alt;
        // Use existing 'data-lightbox-group' or generate a unique ID.
        const groupId =
          a.getAttribute('data-lightbox-group') ?? `tobii-${index}`;
        // Set 'data-group' attribute to value of  'data-lightbox-container'.
        a.setAttribute('data-group', groupId);
        // Set 'data-caption' attribute.
        a.setAttribute('data-caption', caption);
        refresh = true;
      });
      if (refresh) {
        refreshTobii();
      }
    },
  };
})(Drupal, once, window.Tobii);
