<?php

namespace Drupal\lightbox_responsive_tobii\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\Crypt;
use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\lightbox_responsive\Plugin\Field\FieldFormatter\LightboxResponsiveImageFormatter;

/**
 * Plugin implementation of the 'responsive_lightbox_tobii' formatter.
 */
#[FieldFormatter(
  id: 'lightbox_responsive_tobii',
  label: new TranslatableMarkup('Lightbox responsive image with Tobii'),
  field_types: [
    'image',
  ],
)]
class LightboxResponsiveTobiiFormatter extends LightboxResponsiveImageFormatter {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = parent::viewElements($items, $langcode);

    // Allow grouping images of a multivalued field in one Tobii gallery.
    $tobii_id = 'tobii--' . Crypt::randomBytesBase64(4);
    foreach ($elements as $delta => $element) {
      $elements[$delta]['#attributes']['data-lightbox-group'] = $tobii_id;
    }

    $elements['#attached']['library'][] = 'lightbox_tobii/tobii';

    return $elements;
  }

}
